$variant: 'light';
$tint: 'no-tint';

@import 'colors';
@import 'drawing';
@import 'common';
@import 'applications';
@import 'lightdm';
@import 'ubiquity';
@import 'colors-public';
@import 'libhandy';