#!/usr/bin/python3

# Mint-X
X_HEX_ACCENTS = ["#9ab87c", "#accd8a"]

x_hex_colors = {}
x_hex_colors["Aqua"] = "#6cabcd"
x_hex_colors["Blue"] = "#5b73c4"
x_hex_colors["Brown"] = "#aa876a"
x_hex_colors["Grey"] = "#9d9d9d"
x_hex_colors["Orange"] = "#db9d61"
x_hex_colors["Pink"] = "#c76199"
x_hex_colors["Purple"] = "#8c6ec9"
x_hex_colors["Red"] = "#c15b58"
x_hex_colors["Sand"] = "#c8ac69"
x_hex_colors["Teal"] = "#5aaa9a"

X_RGB_ACCENTS = ["172, 205, 138", "#accd8a"]

x_rgb_colors = {}
x_rgb_colors["Aqua"] = "108, 171, 205"
x_rgb_colors["Blue"] = "91, 115, 196"
x_rgb_colors["Brown"] = "170, 135, 106"
x_rgb_colors["Grey"] = "157,157,157"
x_rgb_colors["Orange"] = "219, 157, 97"
x_rgb_colors["Pink"] = "199, 97, 153"
x_rgb_colors["Purple"] = "140, 110, 201"
x_rgb_colors["Red"] = "193, 91, 88"
x_rgb_colors["Sand"] = "200, 172, 105"
x_rgb_colors["Teal"] = "90, 170, 154"


# Mint-Y
Y_HEX_ACCENT1 = ["#35a854"]  # BASE
Y_HEX_ACCENT2 = ["#35a854"]  # DARK

y_hex_colors1 = {}
y_hex_colors2 = {}

y_hex_colors1["Aqua"] = "#1f9ede"
y_hex_colors2["Aqua"] = "#1f9ede"

y_hex_colors1["Blue"] = "#0c75de"
y_hex_colors2["Blue"] = "#0c75de"

y_hex_colors1["Grey"] = "#70737a"
y_hex_colors2["Grey"] = "#70737a"

y_hex_colors1["Orange"] = "#ff7139"
y_hex_colors2["Orange"] = "#ff7139"

y_hex_colors1["Pink"] = "#e54980"
y_hex_colors2["Pink"] = "#e54980"

y_hex_colors1["Purple"] = "#8c5dd9"
y_hex_colors2["Purple"] = "#8c5dd9"

y_hex_colors1["Red"] = "#e82127"
y_hex_colors2["Red"] = "#e82127"

y_hex_colors1["Sand"] = "#c5a07c"
y_hex_colors2["Sand"] = "#c5a07c"

y_hex_colors1["Teal"] = "#199ca8"
y_hex_colors2["Teal"] = "#199ca8"
