style "spinbutton" 
{
    bg[NORMAL] = @bg_color 
    bg[ACTIVE] = shade (0.85, @bg_color) # Color for pressed-spinbuttons.
    
    engine "murrine"
    {
        arrowstyle = 1
        gradient_shades	= {1.1, 1.1, 0.94, 0.94}
        highlight_shade = 1.0
        lightborderstyle = 0
    }
}

style "button"
{   
    #GtkWidget::interior-focus = 1
    
    xthickness = 3
    ythickness = 4
    
    engine "pixmap"
    {
        image
        {
            function = BOX
            detail = "buttondefault"
            recolorable = TRUE
            file = "images/button/button-default.svg"
            border = { 4, 4, 4, 4 }
            stretch = TRUE      
        }  
        image
        {
            function = BOX
            state = PRELIGHT
            shadow = OUT
            recolorable = TRUE
            file = "images/button/button-hover.svg"
            border = { 4, 4, 4, 4 }
            stretch = TRUE
        }
        image
        {
            function = BOX
            state = ACTIVE
            file = "images/button/button-active.svg"
            border =  { 4, 4, 4, 4 }
            stretch = TRUE
        }
        image    
        {
            function = BOX
            shadow = IN
            state = PRELIGHT
            overlay_file = "images/button/button-active-hover.svg"
            overlay_border = { 4, 4, 4, 4 }
            overlay_stretch = TRUE
        }
        image 
        {
            function = BOX
            state = INSENSITIVE
            file = "images/button/button-insensitive.svg"
            border = { 4, 4, 4, 4 }
            stretch = TRUE
        }
        image 
        {
            function = BOX
            file = "images/button/button.svg"        
            border = { 4, 4, 4, 4 }
            stretch = TRUE
        }
        #image 
        #{
        #    function = FOCUS
        #    file = "images/button/button-focus.svg"
        #    border = { 3, 3, 3, 3 }
        #    stretch = TRUE
        #}
    }
}

style "tool-button"
{   
    GtkWidget::interior-focus = 1
    
    xthickness = 3
    ythickness = 4
    
    engine "pixmap"
    {
        image
        {
            function = BOX
            detail = "buttondefault"
            recolorable = TRUE
            file = "images/button/button-default.svg"
            border = { 4, 4, 4, 4 }
            stretch = TRUE      
        }  
        image
        {
            function = BOX
            state = PRELIGHT
            shadow = OUT
            recolorable = TRUE
            file = "images/button/button-hover.svg"
            border = { 4, 4, 4, 4 }
            stretch = TRUE
        }
        image
        {
            function = BOX
            state = ACTIVE
            file = "images/button/button-active.svg"
            border =  { 4, 4, 4, 4 }
            stretch = TRUE
        }
        image    
        {
            function = BOX
            shadow = IN
            state = PRELIGHT
            overlay_file = "images/button/button-active-hover.svg"
            overlay_border = { 4, 4, 4, 4 }
            overlay_stretch = TRUE
        }
        image 
        {
            function = BOX
            state = INSENSITIVE
            file = "images/button/button-insensitive.svg"
            border = { 4, 4, 4, 4 }
            stretch = TRUE
        }
        image 
        {
            function = BOX
            file = "images/button/button.svg"        
            border = { 4, 4, 4, 4 }
            stretch = TRUE
        }
        image 
        {
            function = FOCUS
            file = "images/other/null.png"
            border = { 0, 0, 0, 0 }
            stretch = TRUE
        }
    }
}
