style "scale"
{
    bg[NORMAL] = shade (1.3, @bg_color) 
    bg[PRELIGHT] = shade (1.10, @bg_color)  
    bg[ACTIVE] = shade (0.9, @bg_color)
    bg[SELECTED] = shade (1.0, @selected_bg_color)  
    bg[INSENSITIVE] = shade (0.95, @bg_color)
    
    engine "murrine" 
    {
        focusstyle = 0
        glowstyle = 4
        gradient_shades = {1.0, 1.0, 0.9, 0.9}
        contrast = 1.10
        highlight_shade = 1.05
        lightborderstyle = 1
        border_shades = {1.0, 0.75}
        reliefstyle = 3
        roundness = 7
        trough_shades = {0.9, 1.1}
        #trough_border_shades = {1.20, 1.20}
    }
}

style "murrine-scrollbar" 
{
    xthickness = 1
    ythickness = 2
    
    bg[NORMAL] = shade (0.95, @bg_color)
    bg[SELECTED] = shade (0.8, @base_color)
    bg[ACTIVE] = shade (0.90, @bg_color)
    bg[PRELIGHT] = shade (0.90, @bg_color)
    
    engine "murrine" 
    {
        gradient_shades = {1.1, 1.1, 0.98, 0.98}
        highlight_shade = 1.0
        roundness = 8
        border_shades = {0.80, 0.80}
        contrast = 0.4
        #trough_shades = {0.9, 0.9}
    }
}

style "progressbar" 
{
    xthickness = 0
    ythickness = 0
    
    fg[PRELIGHT] = @selected_fg_color
    bg[NORMAL] = shade (1.06, @bg_color) 
    bg[ACTIVE] = shade (0.85, @base_color)
    bg[SELECTED] = shade (1.0, @selected_bg_color)  
    bg[INSENSITIVE] = shade (0.95, @bg_color)

    engine "murrine" {
        animation = FALSE
        contrast = 1.2
        highlight_shade = 1.0
        shadow_shades = {0.5, 0.0}
        lightborderstyle = 0
        lightborder_shade = 1.1
        trough_shades = { 1.0, 1.16}
        gradient_shades = {1.1,1.1,0.95,0.95}
        border_shades = { 1.1, 1.1 }
        progressbarstyle = 0
        roundness = 2
    }
}

style "scrollbar"
{
    #xthickness = 1
    #ythickness = 1
    
    engine "pixmap"
    {
        # Troughs
        
        image
        {
            function = BOX
            recolorable = TRUE
            detail = "trough"
            file = "images/scroll/trough-v.svg"
            border = {3, 3, 7, 7}
            stretch = TRUE
            orientation = VERTICAL
        }
        image
        {
            function = BOX
            recolorable = TRUE
            detail = "trough"
            file = "images/scroll/trough-h.svg"
            border = {7, 7, 3, 3}
            stretch = TRUE
            orientation = HORIZONTAL
        }
        
        # Sliders
        
        image
        {
            function = SLIDER
            recolorable = TRUE
            state = NORMAL
            file = "images/scroll/slider-v.svg"
            border = {5, 5, 7, 7}
            stretch = TRUE
            orientation = VERTICAL
        }
        image
        {
            function = SLIDER
            recolorable = TRUE
            state = PRELIGHT
            file = "images/scroll/slider-v-hover.svg"
            border = {5, 5, 7, 7}
            stretch = TRUE
            orientation = VERTICAL
        }
        image
        {
            function = SLIDER
            recolorable = TRUE
            state = ACTIVE
            file = "images/scroll/slider-v-hover.svg"
            border = {5, 5, 7, 7}
            stretch = TRUE
            orientation = VERTICAL
        }
        image
        {
            function = SLIDER
            recolorable = TRUE
            state = INSENSITIVE
            file = "images/scroll/slider-v-insensitive.svg"
            border = {5, 5, 7, 7}
            stretch = TRUE
            orientation = VERTICAL
        }
        image
        {
            function = SLIDER
            recolorable = TRUE
            state = NORMAL
            file = "images/scroll/slider-h.svg"
            border = {7, 7, 5, 5}
            stretch = TRUE
            orientation = HORIZONTAL
        }
        image
        {
            function = SLIDER
            recolorable = TRUE
            state = PRELIGHT
            file = "images/scroll/slider-h-hover.svg"
            border = {7, 7, 5, 5}
            stretch = TRUE
            orientation = HORIZONTAL
        }
        image
        {
            function = SLIDER
            recolorable = TRUE
            state = ACTIVE
            file = "images/scroll/slider-h-hover.svg"
            border = {7, 7, 5, 5}
            stretch = TRUE
            orientation = HORIZONTAL
        }
        image
        {
            function = SLIDER
            recolorable = TRUE
            state = INSENSITIVE
            file = "images/scroll/slider-h-insensitive.svg"
            border = {7, 7, 5, 5}
            stretch = TRUE
            orientation = HORIZONTAL
        }
    }
}
