style "inkscape-toolbar"
{
    engine "pixmap"
    {
        image
        {
            function = BOX
            file = "images/toolbars/toolbar.svg"
            border = {0, 0, 0, 1}
            stretch = TRUE
        }
        image
        {
            function = FLAT_BOX
            file = "images/toolbars/toolbar.svg"
            border = {0, 0, 0, 1}
            stretch = TRUE
        }
    }
}

# Fix the appearance of the main toolbar handlebox
widget "gtkmm__GtkWindow.SPDesktopWidget.GtkVBox.GtkHandleBox" style:highest "inkscape-toolbar"
# Fix the appearance of the main toolbar color picker
widget "gtkmm__GtkWindow.SPDesktopWidget.GtkVBox.GtkHandleBox*EventBox" style:highest "inkscape-toolbar"
