//apps rely on some named colors to be exported

// Sass thinks we're using the colors in the variables as strings and may shoot
// warning, it's innocuous and can be defeated by using "" + $var
@define-color theme_fg_color #{"" + $fg_color};
@define-color theme_text_color #{"" + $text_color};
@define-color theme_bg_color #{"" + $bg_color};
@define-color theme_base_color #{"" + $base_color};
@define-color theme_selected_bg_color #{"" + $selected_bg_color};
@define-color theme_selected_fg_color #{"" + $selected_fg_color};
@define-color fg_color #{"" + $fg_color};
@define-color text_color #{"" + $text_color};
@define-color bg_color #{"" + $bg_color};
@define-color base_color #{"" + $base_color};
@define-color selected_bg_color #{"" + $selected_bg_color};
@define-color selected_fg_color #{"" + $selected_fg_color};
@define-color insensitive_bg_color #{"" + $insensitive_bg_color};
@define-color insensitive_fg_color alpha(#{"" + opacify($insensitive_fg_color, 1)}, 0.5);
@define-color insensitive_base_color #{"" + $base_color};
@define-color theme_unfocused_fg_color #{"" + $fg_color};
@define-color theme_unfocused_text_color #{"" + $text_color};
@define-color theme_unfocused_bg_color #{"" + $bg_color};
@define-color theme_unfocused_base_color #{"" + $base_color};
@define-color borders #{"" + $borders_color};
@define-color unfocused_borders #{"" + $borders_color};

@define-color warning_color #{"" + $warning_color};
@define-color error_color #{"" + $error_color};
@define-color success_color #{"" + $success_color};
@define-color placeholder_text_color #{#A8A8A8};

@define-color content_view_bg #{"" + $base_color};

//WM
$wm_bg_unfocused: opacify($header_bg_backdrop, 1);

@define-color wm_title #{"" + $wm_title};
@define-color wm_title_unfocused #{"" + $wm_title_unfocused};

@define-color wm_bg #{"" + $wm_bg};
@define-color wm_bg_unfocused #{"" + $wm_bg_unfocused};

@define-color wm_highlight #{"" + $wm_highlight};
@define-color wm_border #{"" + $wm_border};
@define-color wm_border_unfocused #{"" + $wm_border_unfocused};
@define-color wm_shadow alpha(#{"" + black}, 0.35);

//WM Buttons

// Close
@define-color wm_button_close_bg #{"" + $wm_button_close_bg};
@define-color wm_button_close_hover_bg #{"" + $wm_button_close_hover_bg};
@define-color wm_button_close_active_bg #{"" + $wm_button_close_active_bg};

@define-color wm_icon_close_bg #{"" + $wm_icon_close_bg};

// Minimize, Maximize
@define-color wm_button_hover_bg #{"" + $wm_button_hover_bg};
@define-color wm_button_active_bg #{"" + $wm_button_active_bg};

@define-color wm_icon_bg #{"" + $wm_icon_bg};
@define-color wm_icon_unfocused_bg #{"" + $wm_icon_unfocused_bg};
@define-color wm_icon_hover_bg #{"" + $wm_icon_hover_bg};
@define-color wm_icon_active_bg #{"" + $wm_icon_active_bg};

